@@ -230,6 +230,18 @@ class PandasDataFrameRoundtrip(DiskTestCase):
             df_from_array2 = tiledb.open_dataframe(csv_array_uri2)
             tm.assert_frame_equal(df_orig, df_from_array2)
 
+        # test timestamp write
+        uri2 = self.path("dataframe_csv_timestamp")
+        timestamp = random.randint(0, np.iinfo(np.int64).max)
+        tiledb.from_csv(uri2, csv_uri, timestamp=0, index_col=0)
+        tiledb.from_pandas(uri2, df_orig, timestamp=timestamp,
+                           mode='append', row_start_idx=0, index_col=0)
+
+        with tiledb.open(uri2, timestamp=0) as A:
+            self.assertEqual(A.timestamp, 0)
+        with tiledb.open(uri2, timestamp=timestamp) as A:
+            self.assertEqual(A.timestamp, timestamp)
+
     def test_dataframe_index_to_sparse_dims(self):
         # This test
         # - loops over all of the columns from make_basic_dataframe,
@@ -266,7 +278,8 @@ class PandasDataFrameRoundtrip(DiskTestCase):
                 nonempty = A.nonempty_domain()[0]
                 res = A.multi_index[nonempty[0]:nonempty[1]]
 
-                res_df = pd.DataFrame(res, index=res.pop(col))
+                index = pd.Index(res.pop(col), name=col)
+                res_df = pd.DataFrame(res, index=index)
                 tm.assert_frame_equal(new_df, res_df, check_like=True)
 
     def test_dataframe_multiindex_dims(self):
@@ -377,7 +390,7 @@ class PandasDataFrameRoundtrip(DiskTestCase):
                         index_col=['int_vals'],
                         parse_dates=['time'],
                         sparse=True, allows_duplicates=True,
-                        float_precision='round-trip')
+                        float_precision='round_trip')
 
         with tiledb.open(tmp_array2b) as A:
             self.assertTrue(A.schema.sparse)
